XSL Parameter Reference

# XMLRésuméLibrary: User Guide

zip | Part II. Reference | address.format

# XSL Parameter Reference

Parameters are settings that affect all files that are generated by the XSL templates. They are analogous to attributes that affect everything instead of just one element.

This section is a partial listing of user-configurable parameters. There are many more tunable parameters in `params.xsl`. Take a look at the file in a text editor if you're interested.

zip | Part II. Reference | address.format